@@ -317,13 +317,13 @@ class GitScribeServer:
                 logger.info("Setting up stdio server...")
                 async with stdio_server() as (read_stream, write_stream):
                     logger.info("Starting MCP server run loop...")
+                    
                     await self.server.run(
                         read_stream,
                         write_stream,
                         InitializationOptions(
                             server_name="gitscribe",
-                            server_version="1.0.5",
-                            capabilities=self.server.get_capabilities()
+                            server_version="1.0.8"
                         )
                     )
                     logger.info("MCP server run loop completed normally")
